////////////////////////////////////////////////////////////////////////
//  rpud : An R package for GPU computing
//  Copyright (C) 2010-2014 Chi Yau. All Rights Reserved.
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; version 3 of the License.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, see <http://www.gnu.org/licenses/>.


#include "rpud.h"
#include "inc/rpudev.h"


const char 
    gProductName[] = "Rpud 0.7.1",
    gURL[] = "http://www.r-tutor.com",
    gCopyright[] = "Copyright (C) 2010-2020 Chi Yau. All Rights Reserved.",
    gLicense[] = "Rpud is licensed under GNU GPL v3. " \
                 "There is absolutely NO warranty.";


////////////////////////////////////////////////////////////////////////
// onLoad
//
void onLoad() {

    rpu::printf("%s\n%s\n%s\n%s\n", gProductName, gURL, gCopyright, gLicense);
}


////////////////////////////////////////////////////////////////////////
// onUnload
//
void onUnload() {

}


////////////////////////////////////////////////////////////////////////
// getDevice
//
void getDevice(PInteger pDevice) {

    try {
        rpuSafeCall(cudaGetDevice(pDevice));

        cudaDeviceProp prop;
        rpuSafeCall(cudaGetDeviceProperties(&prop, *pDevice));
        rpu::printf("%s GPU\n", prop.name);

    } catch (const std::exception& e) {
        error(e.what());
    } catch (...) {
        error("Unknown error");
    }

}


////////////////////////////////////////////////////////////////////////
// setDevice
//
void setDevice(PInteger pDevice) {

    try {
        rpuSafeCall(cudaSetDevice(*pDevice));

    } catch (const std::exception& e) {
        error(e.what());
    } catch (...) {
        error("Unknown error");
    }

}


////////////////////////////////////////////////////////////////////////
// countDevices
//
void countDevices(PInteger pCount) {

    try {
        rpuSafeCall(cudaGetDeviceCount(pCount));

        cudaDeviceProp prop;
        for (int i = 0; i < *pCount; i++) {
            rpuSafeCall(cudaGetDeviceProperties(&prop, i));
            rpu::printf("%s GPU\n", prop.name);
        }

    } catch (const std::exception& e) {
        error(e.what());
    } catch (...) {
        error("Unknown error");
    }

}


////////////////////////////////////////////////////////////////////////
// rpu
//

namespace rpu {


void printf(const char* fmt, ...) {

    char buf[RPU_BUFSIZE];
    std::va_list arg;
    va_start(arg, fmt);
    std::vsprintf(buf, fmt, arg);
    va_end(arg);

#ifdef _RPUD_
    Rprintf("%s", buf);
#else
    std::printf("%s", buf);
#endif
}

}	// namespace rpu





